# Methods and Research Design

## Design of scalable, dynamics-driven drug-response networks using ordinary differential equation (ODE) modelling

## Generalised architecture of the drug interaction network

### Selection of nominal initial condition and parameter values

## Generation of synthetic data using ODE models

### Creating basal expression and drug response datasets using a population of ODE models

### Creating datasets containing dynamic information of ODE models

### Design and implementation of a ground truth-driven benchmarking system to evaluate dynamics-driven drug response prediction (DRP)

### Uncertainty Introduction Protocols (Model Perturbation)

### Impact of incomplete knowledge

#### Introducing measurement noise

#### Introducing modelling errors

### ML Benchmarking & Evaluation

### Machine learning models used

### Evaluation metrics used

### Model evaluation and validation protocols
